package commons;

import java.util.ArrayList;

import org.springframework.security.Authentication;
import org.springframework.security.GrantedAuthority;
import org.springframework.security.context.SecurityContextHolder;
import org.springframework.security.userdetails.UserDetails;

import exception.ACLSecurityException;


public class BibliotekaThreadContext
{
  private static ThreadLocal<BibliotekaThreadContext> context = new ThreadLocal<BibliotekaThreadContext>();

  private boolean                                isSecurityFilterEnabled = false;

  private String                                 aclRola;

  private boolean                                isSafeWrite = false;

  public static String getAclRola()
  {
    return getContext().aclRola;
  }

  public static void setAclRola(String aclRola)
  {
    getContext().aclRola = aclRola;
  }

  private BibliotekaThreadContext()
  {
    isSecurityFilterEnabled = false;
  }

  public static boolean isSafeWrite()
  {
    return getContext().isSafeWrite;
  }

  public static void setSafeWrite(boolean isSafeWrite1)
  {
    BibliotekaThreadContext.getContext().isSafeWrite = isSafeWrite1;
  }

  public static boolean isSecurityFilterEnabled()
  {
    return getContext().isSecurityFilterEnabled;
  }

  public static void setSecurityFilterEnabled(boolean isFilterApplied)
  {
    BibliotekaThreadContext.getContext().isSecurityFilterEnabled = isFilterApplied;
  }

  public static String getLogin()
  {
    Authentication authentication = SecurityContextHolder.getContext().getAuthentication();

    if (authentication == null)
      throw new ACLSecurityException("user not authenicated");

    Object obj = authentication.getPrincipal();
    if (obj instanceof UserDetails)
    {
      UserDetails ud = (UserDetails) obj;
      return ud.getUsername();
    }

    throw new SecurityException("unknown UserDetails");

  }


  public static String[] getGroups()
  {
    Authentication authentication = SecurityContextHolder.getContext().getAuthentication();

    if (authentication == null)
      throw new ACLSecurityException("user not authenicated");

    GrantedAuthority[] ga = authentication.getAuthorities();

    if (ga == null) 
    {
      return null;
    }
    
    ArrayList<String> lista = new ArrayList<String>();

    for (int i = 0; i < ga.length; i++)
    {
      String s = ga[i].getAuthority();
      if (!s.startsWith("Role_") || s.equals("Role_Admin"))
        lista.add(s);
    }

    return (String[]) lista.toArray(new String[0]);
  }

  public static String[] getRolesAuthorities()
  {
    Authentication authentication = SecurityContextHolder.getContext().getAuthentication();

    if (authentication == null)
      throw new ACLSecurityException("user not authenicated");

    GrantedAuthority[] ga = authentication.getAuthorities();

    ArrayList<String> lista = new ArrayList<String>();

    for (int i = 0; i < ga.length; i++)
    {
      lista.add(ga[i].getAuthority());
    }

    return (String[]) lista.toArray(new String[0]);
  }

  public static String[] getRoles()
  {
    Authentication authentication = SecurityContextHolder.getContext().getAuthentication();

    if (authentication == null)
      throw new ACLSecurityException("user not authenicated");

    GrantedAuthority[] ga = authentication.getAuthorities();

    ArrayList<String> lista = new ArrayList<String>();

    for (int i = 0; i < ga.length; i++)
    {
      String s = ga[i].getAuthority();
      if (s.startsWith("Role_"))
        lista.add(s);
    }

    return (String[]) lista.toArray(new String[0]);
  }

  public static BibliotekaThreadContext getContext()
  {
    BibliotekaThreadContext ctx = context.get();
    if (ctx == null)
    {
      ctx = new BibliotekaThreadContext();
      context.set(ctx);
    }

    return ctx;
  }
  
 
}