package commons.editor;

import java.beans.PropertyEditorSupport;
import java.text.DateFormat;
import java.text.ParseException;
import java.util.Date;
import java.util.Locale;

import org.springframework.util.StringUtils;

public class DateEditor extends PropertyEditorSupport {

	private DateFormat dateFormat;
	
	public DateEditor()
	{

	}

	public DateEditor(Locale locale)
	{
	  super();
	  dateFormat = DateFormat.getDateInstance(DateFormat.MEDIUM, locale);
	}

	/**
	 * Parse the Date from the given text, using the specified DateFormat.
	 */
	public void setAsText(String text) throws IllegalArgumentException {
		if (!StringUtils.hasText(text)) {
			setValue(null);
		}
		else {
			try {
				setValue(dateFormat.parse(text));
			}
			catch (ParseException e) {
				throw new IllegalArgumentException("Could not parse date: " + e.getMessage());
			}
		}
	}

	/**
	 * Format the Date as String, using the specified DateFormat.
	 */
	public String getAsText() {
		Date value = (Date)getValue();
		return (value != null ? dateFormat.format(value) : "");
	}

}
