package commons.security.authentication.event;

import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationEvent;
import org.springframework.context.ApplicationListener;
import org.springframework.security.event.authentication.AbstractAuthenticationFailureEvent;
import org.springframework.security.event.authentication.AuthenticationFailureBadCredentialsEvent;
import org.springframework.security.event.authentication.AuthenticationFailureDisabledEvent;
import org.springframework.security.event.authentication.AuthenticationFailureExpiredEvent;
import org.springframework.security.event.authentication.AuthenticationFailureLockedEvent;
import org.springframework.security.event.authentication.AuthenticationSuccessEvent;

import service.security.UwierzytelnianieZdarzenieService;

public class BibliotekaApplicationSecurityListener implements ApplicationListener
{
  @Autowired
  private UwierzytelnianieZdarzenieService uwierzytelnianieZdarzenieService;
  
  
  protected final Logger                   logger = Logger.getLogger(getClass());

  @Override
  public void onApplicationEvent(ApplicationEvent event)
  {

    if (event instanceof AuthenticationSuccessEvent)
    {
      AuthenticationSuccessEvent e = (AuthenticationSuccessEvent) event;
      uwierzytelnianieZdarzenieService.zarejstrujPomyslneZalogowanie(e.getAuthentication(), e.getTimestamp());
    }
    else if (event instanceof AuthenticationFailureExpiredEvent)
    {
      AbstractAuthenticationFailureEvent e = (AbstractAuthenticationFailureEvent) event;
      uwierzytelnianieZdarzenieService.zarejstrujNiepomyslneZalogowanie(e.getAuthentication(),
          AuthenticationEventType.FailureExpired, e.getTimestamp());
    }
    else if (event instanceof AuthenticationFailureLockedEvent)
    {
      AbstractAuthenticationFailureEvent e = (AbstractAuthenticationFailureEvent) event;
      uwierzytelnianieZdarzenieService.zarejstrujNiepomyslneZalogowanie(e.getAuthentication(),
          AuthenticationEventType.FailureLocked, e.getTimestamp());

    }
    else if (event instanceof AuthenticationFailureDisabledEvent)
    {
      AbstractAuthenticationFailureEvent e = (AbstractAuthenticationFailureEvent) event;
      uwierzytelnianieZdarzenieService.zarejstrujNiepomyslneZalogowanie(e.getAuthentication(),
          AuthenticationEventType.FailureDisabled, e.getTimestamp());

    }
    else if (event instanceof AuthenticationFailureBadCredentialsEvent)
    {
      AuthenticationFailureBadCredentialsEvent e = (AuthenticationFailureBadCredentialsEvent) event;
      uwierzytelnianieZdarzenieService.zarejstrujNiepomyslneZalogowanie(e.getAuthentication(),
          AuthenticationEventType.FailureBadCredentials, e.getTimestamp());
    }
    
  }

  public void setUwierzytelnianieZdarzenieService(UwierzytelnianieZdarzenieService uwierzytelnianieZdarzenieService)
  {
    this.uwierzytelnianieZdarzenieService = uwierzytelnianieZdarzenieService;
  }

}
