package commons.security.hibernate.interceptor;

import java.io.Serializable;

import org.apache.log4j.Logger;
import org.hibernate.EmptyInterceptor;
import org.hibernate.EntityMode;
import org.hibernate.type.Type;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import service.security.AuditLoggerService;

import commons.security.audit.Auditable;

import domain.Ksiazka;
import exception.ACLAccessDeniedException;

@Transactional(propagation = Propagation.MANDATORY)
public class ACLSecurityInterceptor extends EmptyInterceptor
{
  private static final long                        serialVersionUID = 591415667276169762L;

  protected final Logger                           logger           = Logger.getLogger(getClass());

  @Autowired
  private AuditLoggerService                       auditLoggerService;

  @Override
  public boolean onSave(Object entity, Serializable id, Object[] state, String[] propertyNames, Type[] types)
  {
	if (entity.getClass().isAnnotationPresent(Auditable.class))
    {
      auditLoggerService.logSave(entity, id, state, propertyNames, types);
    }

    return super.onSave(entity, id, state, propertyNames, types);
  }

@Override
  public boolean onFlushDirty(Object entity, Serializable id, Object[] currentState, Object[] previousState,
      String[] propertyNames, Type[] types)
  {
    if (entity.getClass().isAnnotationPresent(Auditable.class))
    {
      auditLoggerService.logUpdate(entity, id, currentState, previousState, propertyNames, types);
    }

    return super.onFlushDirty(entity, id, currentState, previousState, propertyNames, types);
  }

  @Override
  public void onDelete(Object entity, Serializable id, Object[] state, String[] propertyNames, Type[] types)
  {

    if (entity.getClass().isAnnotationPresent(Auditable.class))
      auditLoggerService.logDelete(entity, id);

    super.onDelete(entity, id, state, propertyNames, types);
  }
  
  public void setAuditLoggerService(AuditLoggerService auditLoggerService)
  {
    this.auditLoggerService = auditLoggerService;
  }

}
