package controller;

import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.displaytag.tags.TableTagParameters;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.util.StringUtils;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.SessionAttributes;
import org.springframework.web.bind.support.SessionStatus;

import service.security.UwierzytelnianieZdarzenieService;
import domain.commons.PartialList;
import domain.commons.Preselection;
import domain.security.AuditRecord;
import domain.security.UwierzytelnianieZdarzenie;

@Controller
@SessionAttributes(types = Preselection.class)
public class AutentykacjaListController {

	private final static String FORM_VIEW = "security/autentykacjaList";

	@Autowired
	UwierzytelnianieZdarzenieService uwierzytelnianieZdarzenieService;
		
	@RequestMapping(value = "/security/autentykacjaList.html")
	public String getForm(Model model,
			HttpServletRequest request, HttpServletResponse response,
			@ModelAttribute("autentykacjaPreselection") Preselection preselection,
			BindingResult bindingResult, SessionStatus sessionStatus) {
		
		referenceData(model,preselection,request);
		return FORM_VIEW;
	}
	
	@ModelAttribute("autentykacjaPreselection")
	public Preselection formBackingObject() 
	{
		  Preselection preselection = new Preselection(UwierzytelnianieZdarzenie.class);
		  preselection.setActive(true);
		  return preselection;
	}

	  public boolean isExport(HttpServletRequest request)
	  {
			int paramExport = ServletRequestUtils.getIntParameter(request, TableTagParameters.PARAMETER_EXPORTING, -1); 
			return (paramExport!=-1);
	  }
	
	  protected void referenceData(Model model, Object command, HttpServletRequest request) 
	  {
		  Preselection preselection = (Preselection) command;
    
		  preselection.getCriteriaList().clear();
					  
		  String sort = ServletRequestUtils.getStringParameter(request, "sort",null);
		  String dir = ServletRequestUtils.getStringParameter(request, "dir", null);
				
		  if ( StringUtils.hasText( sort ) ) 
		  {
				preselection.setSortProperty(sort);
				preselection.setSortAscending("asc".equals(dir));
				preselection.setCurrentPage(0);
				preselection.setCurrentRow(-1);
		  }
			
		  int page = ServletRequestUtils.getIntParameter(request, "page", -1);
				
		  if ( page >= 1 ) 
		  {
				preselection.setCurrentPage(page - 1);
		  }
	    
		  List<UwierzytelnianieZdarzenie> list = uwierzytelnianieZdarzenieService.findByCriteria(preselection,!isExport(request));
	      PartialList<UwierzytelnianieZdarzenie> partialList = new PartialList<UwierzytelnianieZdarzenie>(preselection, list);
		
		  model.addAttribute("autentykacjaList", partialList);
	  }
	
	
}
