package controller;

import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.displaytag.tags.TableTagParameters;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.util.StringUtils;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.SessionAttributes;
import org.springframework.web.bind.support.SessionStatus;
import org.springframework.web.util.WebUtils;

import service.KsiazkaService;
import service.UzytkownikService;
import dao.commons.criteria.StringLikeCriterion;
import domain.Ksiazka;
import domain.commons.PartialList;
import domain.commons.Preselection;

@Controller
@SessionAttributes(types = Preselection.class)
public class KsiazkaListController {

	private final static String FORM_VIEW = "ksiazka/ksiazkaList";

	@Autowired
	KsiazkaService ksiazkaService;
		
	@Autowired
	UzytkownikService uzytkownikService;
	
	
	@RequestMapping(value = "/ksiazka/ksiazkaList.html")
	public String getForm(Model model,
			HttpServletRequest request, HttpServletResponse response,
			@ModelAttribute("ksiazkaPreselection") Preselection preselection,
			BindingResult bindingResult, SessionStatus sessionStatus) {
		
		referenceData(model,preselection,request);
		return FORM_VIEW;
	}
	
	@RequestMapping(value = "/ksiazka/ksiazkaWypozycz.html")
	public String wypozycz(Model model,
			HttpServletRequest request, HttpServletResponse response,
			@ModelAttribute("ksiazkaPreselection") Preselection preselection,
			BindingResult bindingResult, SessionStatus sessionStatus) {
		
		int ksiazkaId = ServletRequestUtils.getIntParameter(request, "id" , -1);
		
		if (ksiazkaId > 0)
		{
			ksiazkaService.wypozycz(ksiazkaId, uzytkownikService.getZalogowanyUzytkownik().getId());
		}
				
		referenceData(model,preselection,request);
		return FORM_VIEW;
	}
	
	@ModelAttribute("ksiazkaPreselection")
	public Preselection formBackingObject() 
	{
		  Preselection preselection = new Preselection(Ksiazka.class);
		  preselection.setActive(true);
		  return preselection;
	}

	  public boolean isExport(HttpServletRequest request)
	  {
			int paramExport = ServletRequestUtils.getIntParameter(request, TableTagParameters.PARAMETER_EXPORTING, -1); 
			return (paramExport!=-1);
	  }
	
	  protected void referenceData(Model model, Object command, HttpServletRequest request) 
	  {
		  Preselection preselection = (Preselection) command;
    
		  preselection.getCriteriaList().clear();
					  
		  if (StringUtils.hasText(preselection.getSzukanyWyraz()))
		  {
			  preselection.getCriteriaList().add(new StringLikeCriterion("tytul", "tytul", preselection.getSzukanyWyraz()));
		  }	
			
		  String sort = ServletRequestUtils.getStringParameter(request, "sort",null);
		  String dir = ServletRequestUtils.getStringParameter(request, "dir", null);
				
		  if ( StringUtils.hasText( sort ) ) 
		  {
				preselection.setSortProperty(sort);
				preselection.setSortAscending("asc".equals(dir));
				preselection.setCurrentPage(0);
				preselection.setCurrentRow(-1);
		  }
			
		  int page = ServletRequestUtils.getIntParameter(request, "page", -1);
				
		  if ( page >= 1 ) 
		  {
				preselection.setCurrentPage(page - 1);
		  }
	    
		  if (WebUtils.hasSubmitParameter(request, "obsluga"))
		  {
			  preselection.setCurrentPage(0);
		  }
		  	
		  
	      List<Ksiazka> list = ksiazkaService.findByCriteria(preselection,!isExport(request));
	      PartialList<Ksiazka> partialList = new PartialList<Ksiazka>(preselection, list);
		
		  model.addAttribute("ksiazkaList", partialList);
	  }
	
	
}
