package controller;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.util.StringUtils;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.bind.WebDataBinder;
import org.springframework.web.bind.annotation.InitBinder;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.SessionAttributes;
import org.springframework.web.bind.support.SessionStatus;
import org.springframework.web.multipart.MultipartRequest;
import org.springframework.web.multipart.support.ByteArrayMultipartFileEditor;

import service.KsiazkaService;
import service.SlownikService;

import commons.editor.EntityEditor;

import domain.Dzial;
import domain.Ksiazka;
import domain.Slownik;
import domain.Wydawnictwo;
import domain.commons.Preselection;
import domain.enumType.TypPlik;

@Controller
@SessionAttributes(types = KsiazkaCommand.class)
public class KsiazkaRekordController implements ApplicationContextAware {

	private final static String FORM_VIEW = "ksiazka/ksiazkaRekord";
	private final static String LIST_VIEW = "ksiazkaList.html";
	
	private final static String[] pageTitle = {"Dane","Autorzy","Status"};
	private int pageCount = 3;
	
	private ApplicationContext applicationContext;
	
	@Autowired
	KsiazkaService ksiazkaService;
	
	@Autowired
	SlownikService slownikService;
		
	//UzytkownikValidator uzytkownikValidator = new UzytkownikValidator();
	
	@InitBinder
	public void initialization(WebDataBinder binder) 
	{
		binder.registerCustomEditor(Slownik.class, new EntityEditor(applicationContext, "slownikService"));
		binder.registerCustomEditor(byte[].class, new ByteArrayMultipartFileEditor());
	}

	@RequestMapping(method = RequestMethod.GET, value = "/ksiazka/ksiazkaRekord.html")
	public String getForm(
			Model model,
			HttpServletRequest request) {
		
		KsiazkaCommand ksiazkaCommand = new KsiazkaCommand();
		
		int ksiazkaId = ServletRequestUtils.getIntParameter(request, "id" , -1);
		
		if (ksiazkaId > 0)
		{
			ksiazkaCommand.setKsiazka(ksiazkaService.getInitialized(ksiazkaId));
		}
		else
		{
			ksiazkaCommand.setKsiazka(new Ksiazka());
		}
		
		generujDane(model,ksiazkaCommand);
		model.addAttribute("ksiazkaCommand", ksiazkaCommand);
		return FORM_VIEW;
	}

	@RequestMapping(method = RequestMethod.POST, value = "/ksiazka/ksiazkaRekord.html")
	public String submitForm(Model model,
			HttpServletRequest request, HttpServletResponse response,
			@ModelAttribute("ksiazkaCommand") KsiazkaCommand ksiazkaCommand,
			BindingResult bindingResult, SessionStatus sessionStatus) {

		String akcja = ServletRequestUtils.getStringParameter(request, "page" , null);
		int row = ServletRequestUtils.getIntParameter(request, "row", -1);		
		
		if ("Next".equals(akcja))
		{
			ksiazkaCommand.pageUp(pageCount);
		}
		if ("Prev".equals(akcja))
		{
			ksiazkaCommand.pageDown();
		}
		if ("ZapiszAutor".equals(akcja)) 
		{
			ksiazkaCommand.zmienAutor();
		}
		if ("EdycjaAutor".equals(akcja))
		{
		    if (row > -1) ksiazkaCommand.edytujAutor(row);
		}        
		if ("UsunAutor".equals(akcja)) 
		{
			ksiazkaCommand.usunAutor(row);
		}
		if ("Zapisz".equals(akcja))
		{
			ksiazkaCommand.setPlik(((MultipartRequest)request).getFile("plik"));
				
			if (ksiazkaCommand.getPlik() != null && StringUtils.hasText(ksiazkaCommand.getPlik().getOriginalFilename()))
			{
				ksiazkaCommand.getKsiazka().setTypPlik(TypPlik.get(ksiazkaCommand.getPlik().getOriginalFilename().substring(ksiazkaCommand.getPlik().getOriginalFilename().lastIndexOf('.')+1)));
				try {
					ksiazkaCommand.getKsiazka().setPlik(ksiazkaCommand.getPlik().getBytes());
				} catch (Exception e) {	}
			}
						
			ksiazkaService.zapiszKsiazka(ksiazkaCommand.getKsiazka());
		}
		
		if ("Zapisz".equals(akcja)||"Koniec".equals(akcja))
		{
			sessionStatus.setComplete();
			return "redirect:" + LIST_VIEW;
		}
		else
		{
			generujDane(model,ksiazkaCommand);
			return FORM_VIEW;
		}
		

	}
	
	void generujDane(Model model,KsiazkaCommand ksiazkaCommand)
	{

		List<Slownik> dzialList = new ArrayList<Slownik>();
	
		Preselection  preselection = new Preselection(Dzial.class);
		preselection.setActive(true);
		
		dzialList = slownikService.findByCriteria(preselection);
		
		List<Slownik> wydawnictwoList = new ArrayList<Slownik>();
		
		preselection = new Preselection(Wydawnictwo.class);
		preselection.setActive(true);
		
		wydawnictwoList = slownikService.findByCriteria(preselection);
		
		
		model.addAttribute("dzialList", dzialList);
		model.addAttribute("wydawnictwoList", wydawnictwoList);
		model.addAttribute("pageTitleList",pageTitle);
		model.addAttribute("pageCount",pageCount);
		model.addAttribute("page", ksiazkaCommand.getPage());
	}

	public void setApplicationContext(ApplicationContext applicationContext) {
		this.applicationContext = applicationContext;
	}
	
	

}
