package controller;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Locale;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.util.StringUtils;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.bind.WebDataBinder;
import org.springframework.web.bind.annotation.InitBinder;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.SessionAttributes;
import org.springframework.web.bind.support.SessionStatus;
import org.springframework.web.util.WebUtils;

import service.SlownikService;
import service.UzytkownikService;
import service.email.jms.BibliotekaMessageSender;
import validator.UzytkownikValidator;

import commons.editor.DateEditor;
import commons.editor.EntityEditor;

import domain.Slownik;
import domain.Uzytkownik;
import domain.Wojewodztwo;
import domain.commons.Preselection;
import domain.enumType.TypSlownik;

@Controller
@SessionAttributes(types = SlownikCommand.class)
public class SlownikRekordController implements ApplicationContextAware {

	private final static String FORM_VIEW = "slownik/slownikRekord";
	private final static String LIST_VIEW = "slownikList.html";
	
	private ApplicationContext applicationContext;
	
	@Autowired
	SlownikService slownikService;
	
	@InitBinder
	public void initialization(WebDataBinder binder) {
		binder.registerCustomEditor(Slownik.class, new EntityEditor(applicationContext, "slownikService"));
		binder.registerCustomEditor(Date.class, "dataZakonczeniaKursu",	new DateEditor());
	}

	@RequestMapping(method = RequestMethod.GET, value = "/slownik/slownikRekord.html")
	public String getForm(
			Model model,
			HttpServletRequest request) {
		
		SlownikCommand slownikCommand = new SlownikCommand();
		
		int slownikId = ServletRequestUtils.getIntParameter(request, "id" , -1);

		
		
		if (slownikId > 0)
		{
			slownikCommand.setSlownik(slownikService.get(slownikId));
			slownikCommand.setTyp(TypSlownik.getTyp(slownikCommand.getSlownik()));
		}
		else
		{
			String typ = ServletRequestUtils.getStringParameter(request, "typ" , null);
			slownikCommand.setSlownik(TypSlownik.getObiekt(typ));
			slownikCommand.setTyp(TypSlownik.getTyp(typ));
		}
		
		model.addAttribute("slownikCommand", slownikCommand);
		return FORM_VIEW;
	}

	@RequestMapping(method = RequestMethod.POST, value = "/slownik/slownikRekord.html")
	public String submitForm(Model model,
			HttpServletRequest request, HttpServletResponse response,
			@ModelAttribute("slownikCommand") SlownikCommand slownikCommand,
			BindingResult bindingResult, SessionStatus sessionStatus) {

		String akcja = ServletRequestUtils.getStringParameter(request, "obsluga" , null);
		
		if ("Zapisz".equals(akcja))
		{
			slownikService.zapiszSlownik(slownikCommand.getSlownik());
		}
		
		sessionStatus.setComplete();
		return "redirect:" + LIST_VIEW+"?typ="+slownikCommand.getTyp().getLabel();
	}
	
	public void setApplicationContext(ApplicationContext applicationContext) {
		this.applicationContext = applicationContext;
	}
	
	

}
