package controller;

import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.displaytag.tags.TableTagParameters;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.util.StringUtils;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.SessionAttributes;
import org.springframework.web.bind.support.SessionStatus;
import org.springframework.web.util.WebUtils;

import service.UzytkownikService;
import dao.commons.criteria.StringLikeCriterion;
import domain.Uzytkownik;
import domain.commons.PartialList;
import domain.commons.Preselection;

@Controller
@SessionAttributes(types = Preselection.class)
public class UzytkownikListController {

	private final static String FORM_VIEW = "uzytkownik/uzytkownikList";

	@Autowired
	UzytkownikService uzytkownikService;
		
	@RequestMapping(value = "/uzytkownik/uzytkownikList.html")
	public String getForm(Model model,
			HttpServletRequest request, HttpServletResponse response,
			@ModelAttribute("uzytkownikPreselection") Preselection preselection,
			BindingResult bindingResult, SessionStatus sessionStatus) {
		
		referenceData(model,preselection,request);
		return FORM_VIEW;
	}
	
	@ModelAttribute("uzytkownikPreselection")
	public Preselection formBackingObject() 
	{
		  Preselection preselection = new Preselection(Uzytkownik.class);
		  preselection.setActive(true);
		  preselection.setPageSize(3);
		  return preselection;
	}

	  public boolean isExport(HttpServletRequest request)
	  {
			int paramExport = ServletRequestUtils.getIntParameter(request, TableTagParameters.PARAMETER_EXPORTING, -1); 
			return (paramExport!=-1);
	  }
	
	  protected void referenceData(Model model, Object command, HttpServletRequest request) 
	  {
		  Preselection preselection = (Preselection) command;
    
		  preselection.getCriteriaList().clear();
					  
		  if (StringUtils.hasText(preselection.getSzukanyWyraz()))
		  {
			  preselection.getCriteriaList().add(new StringLikeCriterion("nazwisko", "nazwisko", preselection.getSzukanyWyraz()));
		  }	
			
		  String sort = ServletRequestUtils.getStringParameter(request, "sort",null);
		  String dir = ServletRequestUtils.getStringParameter(request, "dir", null);
				
		  if ( StringUtils.hasText( sort ) ) 
		  {
				if ("label".equals(sort)) sort = "nazwisko";
			
				preselection.setSortProperty(sort);
				preselection.setSortAscending("asc".equals(dir));
				preselection.setCurrentPage(0);
				preselection.setCurrentRow(-1);
		  }
			
		  int page = ServletRequestUtils.getIntParameter(request, "page", -1);
				
		  if ( page >= 1 ) 
		  {
				preselection.setCurrentPage(page - 1);
		  }
	    
		  if (WebUtils.hasSubmitParameter(request, "obsluga"))
		  {
			  preselection.setCurrentPage(0);
		  }
		  	
		  
	      List<Uzytkownik> list = uzytkownikService.findByCriteria(preselection,!isExport(request));
	      PartialList<Uzytkownik> partialList = new PartialList<Uzytkownik>(preselection, list);
		
		  model.addAttribute("uzytkownikList", partialList);
	  }
	
	
}
