package controller;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.util.StringUtils;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.bind.WebDataBinder;
import org.springframework.web.bind.annotation.InitBinder;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.SessionAttributes;
import org.springframework.web.bind.support.SessionStatus;

import service.KsiazkaService;
import service.SlownikService;
import service.UzytkownikService;
import service.email.jms.BibliotekaMessageSender;
import validator.UzytkownikValidator;

import commons.editor.DateEditor;
import commons.editor.EntityEditor;

import domain.Slownik;
import domain.Uzytkownik;
import domain.Wojewodztwo;
import domain.commons.Preselection;

@Controller
@SessionAttributes(types = UzytkownikCommand.class)
public class UzytkownikRekordController implements ApplicationContextAware {

	private final static String FORM_VIEW = "uzytkownik/uzytkownikRekord";
	private final static String LIST_VIEW = "uzytkownikList.html";
	
	private ApplicationContext applicationContext;
	
	@Autowired
	UzytkownikService uzytkownikService;
	
	@Autowired
	SlownikService slownikService;
	
	@Autowired
	KsiazkaService ksiazkaService;
	
	//@Autowired
	BibliotekaMessageSender bibliotekaMessageSender;
		
	UzytkownikValidator uzytkownikValidator = new UzytkownikValidator();
	
	@InitBinder
	public void initialization(WebDataBinder binder) {
		binder.registerCustomEditor(Slownik.class, new EntityEditor(applicationContext, "slownikService"));
		binder.registerCustomEditor(Date.class, "dataZakonczeniaKursu",	new DateEditor());
	}

	@RequestMapping(method = RequestMethod.GET, value = "/uzytkownik/uzytkownikRekord.html")
	public String getForm(
			Model model,
			HttpServletRequest request) {
		
		UzytkownikCommand uzytkownikCommand = new UzytkownikCommand();
		
		int uzytkownikId = ServletRequestUtils.getIntParameter(request, "id" , -1);
		
		if (uzytkownikId > 0)
		{
			uzytkownikCommand.setUzytkownik(uzytkownikService.getInitialized(uzytkownikId));
		}
		else
		{
			uzytkownikCommand.setUzytkownik(new Uzytkownik());
		}
		
		generujDane(model);
		model.addAttribute("uzytkownikCommand", uzytkownikCommand);
		return FORM_VIEW;
	}

	@RequestMapping(method = RequestMethod.POST, value = "/uzytkownik/uzytkownikRekord.html")
	public String submitForm(Model model,
			HttpServletRequest request, HttpServletResponse response,
			@ModelAttribute("uzytkownikCommand") UzytkownikCommand uzytkownikCommand,
			BindingResult bindingResult, SessionStatus sessionStatus) {

		String akcja = ServletRequestUtils.getStringParameter(request, "obsluga" , null);
		
		if ("Mail".equals(akcja))
		{
			if (StringUtils.hasText(uzytkownikCommand.getUzytkownik().getLogin()))
			{
				bibliotekaMessageSender.kontaktMessage(uzytkownikCommand.getUzytkownik().getLogin());
			}
			generujDane(model);
			return FORM_VIEW;
		}
		
		if ("Zapisz".equals(akcja))
		{
			uzytkownikValidator.validate(uzytkownikCommand, bindingResult);
			
			if (bindingResult.getErrorCount() > 0 )
			{
				generujDane(model);
				return FORM_VIEW;
			}
			
			uzytkownikService.zapiszUzytkownik(uzytkownikCommand.getUzytkownik());
		}
		
		if ("Oddaj".equals(akcja))
		{
			
			int ksiazkaId = ServletRequestUtils.getIntParameter(request, "row" , -1);
			
			if (ksiazkaId > 0)
			{
				ksiazkaService.oddaj(ksiazkaId);
			}
						
			//generujDane(model);
			return "redirect:" + "uzytkownikRekord.html?id=" + uzytkownikCommand.getUzytkownik().getId();
		}
		
		sessionStatus.setComplete();
		return "redirect:" + LIST_VIEW;
	}
	
	void generujDane(Model model)
	{

		List<Slownik> wojewodztwoList = new ArrayList<Slownik>();
	
		Preselection  preselection = new Preselection(Wojewodztwo.class);
		preselection.setActive(true);
		
		wojewodztwoList = slownikService.findByCriteria(preselection);
		
		model.addAttribute("wojewodztwoList", wojewodztwoList);
	
	}

	public void setApplicationContext(ApplicationContext applicationContext) {
		this.applicationContext = applicationContext;
	}

}
