package dao.commons;

import java.util.List;

import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import dao.commons.criteria.Criterion;
import domain.commons.Preselection;

public interface GenericDAO<T extends Object>
{
  public T get(int id);

  public void update(T entity);

  public void save(T entity);
  
  public void saveOrUpdate(T entity);

  public void delete(T entity);

  public void refresh(T entity);
  
  public void evict(Object entity);
  
  public void persist(Object entity);
  
  public boolean exists(int id);
  
  public void initialize(Object proxy);
  
  public void flush();

  public List<T> findByCriteria(Preselection preselection);
  
  public List<T> findByCriteria(Preselection preselection, boolean ograniczona);
  
  public List<T> findByFirstLetter(List<Criterion> criteriaList);
  
  List<T> loadAll();

  public void clearSession();
  
  public <Entity extends Object> Entity getReferencedEntity(Class entityClass, int id, String referencedEntity);
  public Integer getReferencedEntityId(Class entityClass, int id, String referencedEntity);
  

}
