package dao.commons.criteria;

import java.util.HashMap;
import java.util.Map;

import org.hibernate.Criteria;
import org.hibernate.criterion.Order;
import org.hibernate.criterion.Projection;
import org.hibernate.criterion.Projections;
import org.springframework.util.StringUtils;

public class CriteriaHelper
{
  private Map<String,Criteria> criteriaMap;
   
  public CriteriaHelper(Criteria criteria)
  {
    criteriaMap = new HashMap<String,Criteria>();
    criteriaMap.put(null, criteria);
  }
  
  public static final String getNestedPath(String path)
  {
    int k = path.lastIndexOf('.');
    return (k > 0) ? path.substring(0, k) : null;
  }
  
  public static final String getNestedProperty(String path)
  {
    int k = path.lastIndexOf('.');
    return (k > 0) ? path.substring(k+1) : path;
  }
  
  private static final String getAliasForNestedPath(String path)
  {
    if ( path == null) {
      return null;
    }
    return '_' + path.replace('.','_');
  }
  
  private static final String getFullPath(String nestedPath, String property)
  {
    if (StringUtils.hasText(nestedPath)) {
      return nestedPath + '.' + property;
    }
    else {
      return property;
    }
  }
  
  public Criteria getSubcriteria(String nestedPath)
  {
    Criteria c = criteriaMap.get(nestedPath);
    if (c == null)
    {
      String parent = getNestedPath(nestedPath);
      String prop = getNestedProperty(nestedPath);
  
      c = getSubcriteria(parent);
      if (c == null)
      {
        return null;
      }
      
      c = c.createCriteria(prop, getAliasForNestedPath(nestedPath), Criteria.LEFT_JOIN); 

      criteriaMap.put(nestedPath, c);
    }
    return c;
  }
  
  public void addOrder(String sortProperty, boolean ascending)
  {
    if (!StringUtils.hasText(sortProperty)) return;
   
    String nestedPath = getNestedPath(sortProperty);
    String property = getNestedProperty(sortProperty);
    
    if (ascending) {
      getSubcriteria(nestedPath).addOrder(Order.asc(property));
    }
    else {
      getSubcriteria(nestedPath).addOrder(Order.desc(property));
    }      
  }    

  public static final Projection getProjectionForSortPropertyPostgresFix(String sortProperty)
  {
    if (!StringUtils.hasText(sortProperty)) {
      return Projections.property("id");
    }
   
    String nestedPath = getNestedPath(sortProperty);
    String property = getNestedProperty(sortProperty);
    
    return Projections.property(getFullPath(getAliasForNestedPath(nestedPath), property));
  }    
 /* 
  public Projection addSumProperty(String sumProperty)
  {
    if ( !StringUtils.hasText(sumProperty))
      return null;
    
    String nestedPath = getNestedPath(sumProperty);
    String property = getNestedProperty(sumProperty);
    
    getSubcriteria(nestedPath);
    
    return Projections.sum(getFullPath(getAliasForNestedPath(nestedPath), property));
  }   
  
  public Projection addProjectionProperty(String projectionProperty)
  {
    if ( !StringUtils.hasText(projectionProperty))
      return null;
    
    String nestedPath = getNestedPath(projectionProperty);
    String property = getNestedProperty(projectionProperty);
    
    getSubcriteria(nestedPath);
    
    return Projections.property(getFullPath(getAliasForNestedPath(nestedPath), property));
  }   
*/
}
