package dao.commons.criteria;

import org.hibernate.Criteria;
import org.hibernate.criterion.Junction;
import org.hibernate.criterion.MatchMode;
import org.hibernate.criterion.Restrictions;
import org.springframework.util.StringUtils;

public class StringLikeCriterion extends AbstractCriterion
{

  private static final long serialVersionUID = -8204168588514038696L;
  
  private String stringLike;

  public StringLikeCriterion(String path, String label, String stringLike)
  {
    super(path, label);
    this.setStringLike(stringLike);
  }

  public String getStringLike()
  {
    return stringLike;
  }


  public void setStringLike(String stringLike)
  {
    this.stringLike = stringLike;
  }


  @Override
  public void prepareCriteria(Criteria criteria)
  {
 	  if (StringUtils.hasText(stringLike)) {
		  String[] stringList = stringLike.split("\\s");
		  Junction junc = Restrictions.disjunction();
		  for (String word : stringList)
		      junc.add(Restrictions.ilike(getProperty(), word, MatchMode.ANYWHERE));
		  criteria.add(junc);
    }
  }
  
}
