package dao.security.authentication;

import java.util.ArrayList;
import java.util.List;

import org.apache.log4j.Logger;
import org.springframework.dao.DataAccessException;
import org.springframework.orm.hibernate3.support.HibernateDaoSupport;
import org.springframework.security.GrantedAuthority;
import org.springframework.security.GrantedAuthorityImpl;
import org.springframework.security.userdetails.User;
import org.springframework.security.userdetails.UserDetails;
import org.springframework.security.userdetails.UserDetailsService;
import org.springframework.security.userdetails.UsernameNotFoundException;
import org.springframework.transaction.annotation.Transactional;

import domain.Uzytkownik;

@Transactional
public class BibliotekaAuthenticationDao extends HibernateDaoSupport implements UserDetailsService
{
  private String         login_HQL;

  protected final Logger logger = Logger.getLogger(getClass());

  public BibliotekaAuthenticationDao()
  {
    super();
  }

  @Transactional(readOnly = true)
  @Override
  public UserDetails loadUserByUsername(String login) throws UsernameNotFoundException,
      DataAccessException
  {
    List<Uzytkownik> uzytkownikList = (List<Uzytkownik>) getHibernateTemplate().findByNamedParam(login_HQL,
        "login", login);

    if (uzytkownikList.size() != 1)
    {
      throw new UsernameNotFoundException("Login not found " + login);
    }

    Uzytkownik uzytkownik = uzytkownikList.get(0);
    GrantedAuthority[] arrayAuths = getAuthorities(uzytkownik);
    
    User authUser = new User(uzytkownik.getLogin(), uzytkownik.getHaslo(), uzytkownik.isAktywny(),
        true, true, true, arrayAuths);

    getHibernateTemplate().flush();
    logger.debug("AuthenticationDao User : " + authUser.toString());

    return authUser;
  }

  private GrantedAuthority[] getAuthorities(Uzytkownik uzytkownik)
  {
    List<String> grantedAuth = new ArrayList<String>();
      
    grantedAuth.add("Authenticated_User");
    
    if (uzytkownik.isAdmin()) grantedAuth.add("Role_Admin");
    
    logger.debug("Authourities granted: " + grantedAuth.toString());

    GrantedAuthority[] ga = new GrantedAuthority[grantedAuth.size()];

    for (int i = 0; i < grantedAuth.size(); i++)
    {
      ga[i] = new GrantedAuthorityImpl(grantedAuth.get(i));
    }

    return ga;
  }

  public void setLogin_HQL(String login_HQL)
  {
    this.login_HQL = login_HQL;
  }

}
