package service;

import java.util.Date;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.Hibernate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import dao.AutorDAO;
import dao.KsiazkaDAO;
import dao.UzytkownikDAO;
import dao.WypozyczenieDAO;
import dao.commons.criteria.IntCriterion;
import dao.commons.criteria.NullCriterion;
import domain.Autor;
import domain.Ksiazka;
import domain.Uzytkownik;
import domain.Wypozyczenie;
import domain.commons.Preselection;

@Service("ksiazkaService")
@Transactional
public class KsiazkaServiceImpl implements KsiazkaService {
	@Autowired
	private KsiazkaDAO ksiazkaDAO;
	@Autowired
	private WypozyczenieDAO wypozyczenieDAO;
	@Autowired
	private AutorDAO autorDAO;
	@Autowired
	private UzytkownikDAO uzytkownikDAO;

	public AutorDAO getAutorDAO() {
		return autorDAO;
	}

	public void setAutorDAO(AutorDAO autorDAO) {
		this.autorDAO = autorDAO;
	}

	protected final Log logger = LogFactory.getLog(getClass());

	public void setKsiazkaDAO(KsiazkaDAO ksiazkaDAO) {
		this.ksiazkaDAO = ksiazkaDAO;
	}

	public void setWypozyczenieDAO(WypozyczenieDAO wypozyczenieDAO) {
		this.wypozyczenieDAO = wypozyczenieDAO;
	}

	@Transactional
	@Override
	public void zapiszKsiazka(Ksiazka ksiazka) {
		if (ksiazka.getId() > 0) {
			ksiazkaDAO.update(ksiazka);
		} else {
			ksiazkaDAO.save(ksiazka);
		}
	}

	@Override
	public Ksiazka get(int id) {
		return ksiazkaDAO.get(id);
	}

	@Override
	public Ksiazka getInitialized(int id) {
		
		Ksiazka ksiazka = ksiazkaDAO.get(id);
		
		if (ksiazka != null) {
			Hibernate.initialize(ksiazka.getListaAutorow());
			Hibernate.initialize(ksiazka.getListaWYpozyczen());
		}
		
		return ksiazka;
	}

	public KsiazkaDAO getKsiazkaDAO() {
		return ksiazkaDAO;
	}

	public Log getLogger() {
		return logger;
	}

	@Override
	public void dodajAutora(int idAutor, int idKsiazka) {

		Ksiazka ksiazka = getInitialized(idKsiazka);
		Autor autor = autorDAO.get(idAutor);

		ksiazka.getListaAutorow().add(autor);

		ksiazkaDAO.saveOrUpdate(ksiazka);
		autorDAO.saveOrUpdate(autor);

	}

	@Override
	public boolean wypozycz(int idKsiazka, int idUzytkownik) {
		Ksiazka ksiazka = getInitialized(idKsiazka);
		Uzytkownik uzytkownik = uzytkownikDAO.get(idUzytkownik);

		if (isDostepna(ksiazka)) {
			Wypozyczenie w = new Wypozyczenie();
			w.setDataWypozyczenia(new Date());
			w.setOpis("opis");
			w.setKsiazka(ksiazka);
			w.setUzytkownik(uzytkownik);
			wypozyczenieDAO.save(w);
			return true;
		}
		return false;
	}

	@Override
	public boolean isDostepna(Ksiazka ksiazka) {
		Preselection preselection = new Preselection(Wypozyczenie.class);
		preselection.setActive(true);
		preselection.getCriteriaList().add(new IntCriterion("ksiazka.id", " ", ksiazka.getId()));
		preselection.getCriteriaList().add(new NullCriterion("dataZwrotu", " "));
		List<Wypozyczenie> listaWypozyczen = wypozyczenieDAO.findByCriteria(preselection);
		if (listaWypozyczen == null || listaWypozyczen.isEmpty()) 
		{
			return true;
		} else {
			return false;
		}
	}

	@Override
	public boolean oddaj(int idKsiazka) {
		
		Preselection preselection = new Preselection(Wypozyczenie.class);
		preselection.setActive(true);
		
		preselection.getCriteriaList().add(new IntCriterion("ksiazka.id", "", idKsiazka));
		preselection.getCriteriaList().add(new NullCriterion("dataZwrotu", " "));
		List<Wypozyczenie> listaWypozyczen = wypozyczenieDAO.findByCriteria(preselection);
		
		if (listaWypozyczen == null || listaWypozyczen.isEmpty()) {
			return false;
		} else {
			listaWypozyczen.get(0).setDataZwrotu(new Date());
			wypozyczenieDAO.update(listaWypozyczen.get(0));
			//listaWypozyczen.get(listaWypozyczen.indexOf((Ksiazka)ksiazkaDAO.getInitialized(idKsiazka))).setDataZwrotu(new Date());
			return true;
		}
	}

	@Override
	public List<Ksiazka> loadAll() {
		return ksiazkaDAO.loadAll();
	}

	public UzytkownikDAO getUzytkownikDAO() {
		return uzytkownikDAO;
	}

	public void setUzytkownikDAO(UzytkownikDAO uzytkownikDAO) {
		this.uzytkownikDAO = uzytkownikDAO;
	}

	public WypozyczenieDAO getWypozyczenieDAO() {
		return wypozyczenieDAO;
	}
	
	@Override
	public List<Ksiazka> findByCriteria(Preselection preselection)
	{
	    return ksiazkaDAO.findByCriteria(preselection);
	}
	  
	@Override
	public List<Ksiazka> findByCriteria(Preselection preselection,boolean ograniczenie)
	{
	    return ksiazkaDAO.findByCriteria(preselection,ograniczenie);
	}

}