package service;

import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.Hibernate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.security.providers.encoding.PasswordEncoder;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import commons.BibliotekaThreadContext;

import dao.UzytkownikDAO;
import domain.Uzytkownik;
import domain.commons.Preselection;

@Service("uzytkownikService")
@Transactional(propagation=Propagation.REQUIRED)
public class UzytkownikServiceImpl implements UzytkownikService {
	
	@Autowired
	@Qualifier("uzytkownikDAO")
	private UzytkownikDAO uzytkownikDAO;
	
	@Autowired
	PasswordEncoder passwordEncoder;
		
	protected final Log logger = LogFactory.getLog(getClass());

	public void setPasswordEncoder(PasswordEncoder passwordEncoder)
	{
	    this.passwordEncoder = passwordEncoder;
	}
	
	public String zaszyfrujHaslo(String plainPassword)
	{
	    return passwordEncoder.encodePassword(plainPassword, null);
	}
		
	@Transactional
	@Override
	public void zapiszUzytkownik(Uzytkownik uzytkownik) {
		
		if (uzytkownik.getId() > 0) {
			uzytkownikDAO.update(uzytkownik);
		} else {
			uzytkownik.setHaslo(zaszyfrujHaslo(uzytkownik.getHaslo()));
			uzytkownik.setAktywny(true);
			uzytkownikDAO.save(uzytkownik);
		}
	}

	@Override
	public Uzytkownik get(int id) {
		return uzytkownikDAO.get(id);
	}

	@Override
	public Uzytkownik getInitialized(int id) {
		
		Uzytkownik uzytkownik = uzytkownikDAO.get(id);
		if (uzytkownik != null) {
			Hibernate.initialize(uzytkownik.getListaWypozyczen());
		}

		return uzytkownik;
	}

	@Override
	public List<Uzytkownik> loadAll() {
		return uzytkownikDAO.loadAll();
	}

	// load All

	public Log getLogger() {
		return logger;
	}

	@Override
	public Uzytkownik getByLogin(String login) {
		return uzytkownikDAO.getByLogin(login);
	}

	@Override
	public void liczbaUzytkownikow() {
		
		List<Uzytkownik> uzytkownikList = uzytkownikDAO.loadAll();
		
		if (uzytkownikList == null || uzytkownikList.isEmpty())
		{
			System.out.println("size: 0");
		}
		else 
		{
			System.out.println("size: " + uzytkownikList.size());
		}
	}
	
	
	@Override
	public List<Uzytkownik> findByCriteria(Preselection preselection)
	{
	    return uzytkownikDAO.findByCriteria(preselection);
	}
	  
	@Override
	public List<Uzytkownik> findByCriteria(Preselection preselection,boolean ograniczenie)
	{
	    return uzytkownikDAO.findByCriteria(preselection,ograniczenie);
	}
	
	@Override
	public Uzytkownik getZalogowanyUzytkownik() 
	{
		Uzytkownik uzytkownik = 	
		uzytkownikDAO.getByLogin(BibliotekaThreadContext.getLogin());

		return uzytkownik;
	}
	

}
