package service.email.mail;

import java.util.Date;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;

import javax.mail.internet.MimeMessage;

import org.apache.log4j.Logger;
import org.apache.velocity.app.VelocityEngine;
import org.springframework.beans.BeansException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.mail.MailException;
import org.springframework.mail.javamail.JavaMailSender;
import org.springframework.mail.javamail.MimeMessageHelper;
import org.springframework.mail.javamail.MimeMessagePreparator;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.ui.velocity.VelocityEngineUtils;

import service.UzytkownikService;
import controller.UzytkownikCommand;
import domain.Uzytkownik;
import domain.types.Plec;

@Transactional
//@Service("mailService")
public class MailServiceImpl implements MailService, ApplicationContextAware {
	private static final Logger log = Logger.getLogger(MailServiceImpl.class);
	@Autowired
	@Qualifier("velocityEngine")
	private VelocityEngine velocityEngine;
	@Autowired
	@Qualifier("mailSender")
	private JavaMailSender mailSender;
	private ApplicationContext ac;
	@Autowired
	@Qualifier("uzytkownikService")
	private UzytkownikService uzytkownikService;
	
	@Override
	public void kontakt(final String login) {
		MimeMessagePreparator preparator = new MimeMessagePreparator() {

			@Override
            public void prepare(MimeMessage mimeMessage) throws Exception {
                Uzytkownik uzytkownik = uzytkownikService.getByLogin(login);
            	MimeMessageHelper message = new MimeMessageHelper(mimeMessage, "UTF-8");
                
                message.setTo(uzytkownik.getLogin());
                message.setFrom(ac.getMessage("common.email.from", null, new Locale("pl")));
                Map<String, Object> model = new HashMap<String, Object>();
                model.put("uzytkownik", uzytkownik);
                String templateLocation = ac.getMessage("common.email.template.kontakt", null, new Locale("pl"));
                String text = "";
                text = VelocityEngineUtils.mergeTemplateIntoString(velocityEngine, templateLocation,
                        "UTF-8", model);
                message.setText(text, false);
                message.setSubject(ac.getMessage("common.email.subject.kontakt", null, new Locale("pl")));
            }

        };
        try {
        	this.mailSender.send(preparator);
        	log.error("---=== message (new message) sent to login " + login + " ===---");
        } catch(MailException me) {
        	log.error("---=== sending message (new message) to login " + login + " failed ===---", me);
        }
	}

	@Override
	public void zwrot(final String login) {
		MimeMessagePreparator preparator = new MimeMessagePreparator() {

			@Override
            public void prepare(MimeMessage mimeMessage) throws Exception {
                Uzytkownik uzytkownik = uzytkownikService.getByLogin(login);
            	MimeMessageHelper message = new MimeMessageHelper(mimeMessage, "UTF-8");
                
                message.setTo(uzytkownik.getLogin());
                message.setFrom(ac.getMessage("common.email.from", null, new Locale("pl")));
                Map<String, Object> model = new HashMap<String, Object>();
                model.put("uzytkownik", uzytkownik);
                String templateLocation = ac.getMessage("common.email.template.zwrot", null, new Locale("pl"));
                String text = "";
                text = VelocityEngineUtils.mergeTemplateIntoString(velocityEngine, templateLocation,
                        "UTF-8", model);
                message.setText(text, false);
                message.setSubject(ac.getMessage("common.email.subject.zwrot", null, new Locale("pl")));
            }

        };
        try {
        	this.mailSender.send(preparator);
        	log.error("---=== message (new message) sent to login " + login + " ===---");
        } catch(MailException me) {
        	log.error("---=== sending message (new message) to login " + login + " failed ===---", me);
        }
	}
	
	///////////////////////////////////////////////////////////////////////////
	// getter / setter
	///////////////////////////////////////////////////////////////////////////
	public void setVelocityEngine(VelocityEngine velocityEngine) {
		this.velocityEngine = velocityEngine;
	}

	public void setMailSender(JavaMailSender mailSender) {
		this.mailSender = mailSender;
	}

	public void setUzytkownikService(UzytkownikService uzytkownikService) {
		this.uzytkownikService = uzytkownikService;
	}

	@Override
	public void setApplicationContext(ApplicationContext ac)
			throws BeansException {
		this.ac = ac;		
	}
}
