package service.security;

import java.sql.Timestamp;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.Authentication;
import org.springframework.security.ui.WebAuthenticationDetails;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import commons.security.authentication.event.AuthenticationEventType;

import dao.security.UwierzytelnianieZdarzenieDAO;
import domain.commons.Preselection;
import domain.security.UwierzytelnianieZdarzenie;

@Transactional(propagation = Propagation.REQUIRES_NEW)
@Service
public class UwierzytelnianieZdarzenieServiceImpl implements UwierzytelnianieZdarzenieService
{
  @Autowired
  private UwierzytelnianieZdarzenieDAO uwierzytelnianieZdarzenieDAO;

  private String getIP(Object details)
  {
    if (details instanceof WebAuthenticationDetails)
    {
      WebAuthenticationDetails wd = (WebAuthenticationDetails) details;
      return wd.getRemoteAddress();
    }

    return null;
  }

  @Override
  public void zarejstrujPomyslneZalogowanie(Authentication auth, long timestamp)
  {
    UwierzytelnianieZdarzenie uz = new UwierzytelnianieZdarzenie();
    uz.setTimestamp(new Timestamp(timestamp));
    uz.setLogin(auth.getName());
    uz.setTypZdarzenia(AuthenticationEventType.Success);
    uz.setIp(getIP(auth.getDetails()));

    uwierzytelnianieZdarzenieDAO.save(uz);
  }

  @Override
  public void zarejstrujNiepomyslneZalogowanie(Authentication auth, AuthenticationEventType authType, long timestamp)
  {
    UwierzytelnianieZdarzenie uz = new UwierzytelnianieZdarzenie();
    uz.setTimestamp(new Timestamp(timestamp));
    uz.setLogin(auth.getName());
    uz.setTypZdarzenia(authType);
    uz.setIp(getIP(auth.getDetails()));

    uwierzytelnianieZdarzenieDAO.save(uz);
  }

  public void setUwierzytelnianieZdarzenieDAO(UwierzytelnianieZdarzenieDAO uwierzytelnianieZdarzenieDAO)
  {
    this.uwierzytelnianieZdarzenieDAO = uwierzytelnianieZdarzenieDAO;
  }

  @Override
  public List<UwierzytelnianieZdarzenie> findByCriteria(
		Preselection preselection, boolean ograniczenie) {
		return uwierzytelnianieZdarzenieDAO.findByCriteria(preselection, ograniczenie);
}

  @Override
  public List<UwierzytelnianieZdarzenie> findByCriteria(Preselection preselection) {
	return uwierzytelnianieZdarzenieDAO.findByCriteria(preselection);
}
  
  

}
