package validator;

import org.apache.commons.validator.EmailValidator;
import org.springframework.util.StringUtils;
import org.springframework.validation.Errors;
import org.springframework.validation.ValidationUtils;
import org.springframework.validation.Validator;

import controller.UzytkownikCommand;

public class UzytkownikValidator implements Validator {

	EmailValidator emailValidator = EmailValidator.getInstance();
	
	@Override
	public boolean supports(Class<?> arg0) {
		return arg0.isAssignableFrom(UzytkownikCommand.class);
	}

	public void validate(UzytkownikCommand uzytkownikCommand, Errors errors) {

		ValidationUtils.rejectIfEmpty(errors, "uzytkownik.imie", "error.field.required");
		ValidationUtils.rejectIfEmpty(errors, "uzytkownik.nazwisko", "error.field.required");
		ValidationUtils.rejectIfEmptyOrWhitespace(errors, "uzytkownik.pesel","error.field.required");
		ValidationUtils.rejectIfEmptyOrWhitespace(errors, "uzytkownik.login","error.field.required");
		
		
		if (StringUtils.hasText(uzytkownikCommand.getUzytkownik().getPesel()))
		{
			if (!PeselValidator.isValid(uzytkownikCommand.getUzytkownik().getPesel()))
			{
				errors.rejectValue("uzytkownik.pesel","error.pesel.invalid");
			}
		}
		
		if (uzytkownikCommand.getUzytkownik().getAdres() != null && StringUtils.hasText(uzytkownikCommand.getUzytkownik().getAdres().getKodPocztowy()))
		{
			if (!KodPocztowyValidator.isValid(uzytkownikCommand.getUzytkownik().getAdres().getKodPocztowy()))
			{
				errors.rejectValue("uzytkownik.adres.kodPocztowy","error.kod.invalid");
			}
		}
		
		if (StringUtils.hasText(uzytkownikCommand.getUzytkownik().getLogin()) 
				&& !emailValidator.isValid(uzytkownikCommand.getUzytkownik().getLogin())) 
		{
			errors.rejectValue("uzytkownik.login", "error.email.invalid");
		}
		
	}

	@Override
	public void validate(Object target, Errors errors) {

	}

}